@@ -4,7 +4,7 @@
 ###############################################################################
 
 setMethod("toJSON", "integer",
-	function(x, container = TRUE, collapse = "\n  ", ..., .level = 1L) {
+	function(x, container = TRUE, collapse = "\n  ", ..., .level = 1L, .withNames=F) {
 		tmp <- as.character(x);
 
 		if(any(missings <- !is.finite(x))){
